.\" ====================================================================
.\"  @Troff-man-file{
.\"     author          = "Nelson H. F. Beebe",
.\"     version         = "1.00",
.\"     date            = "02 December 1998",
.\"     time            = "17:17:42 MST",
.\"     filename        = "wwwseek.man",
.\"     address         = "Center for Scientific Computing
.\"                        University of Utah
.\"                        Department of Mathematics, 322 INSCC
.\"                        155 S 1400 E RM 233
.\"                        Salt Lake City, UT 84112-0090
.\"                        USA",
.\"     telephone       = "+1 801 581 5254",
.\"     FAX             = "+1 801 585 1640, +1 801 581 4148",
.\"     URL             = "http://www.math.utah.edu/~beebe",
.\"     checksum        = "35198 319 1517 10391",
.\"     email           = "beebe@math.utah.edu, beebe@acm.org,
.\"                        beebe@ieee.org (Internet)",
.\"     codetable       = "ISO/ASCII",
.\"     keywords        = "World-Wide Web, search",
.\"     supported       = "yes",
.\"     docstring       = "This file is the UNIX nroff/troff manual
.\"                        page documentation for wwwseek.
.\"
.\"                        The checksum field above contains a CRC-16
.\"                        checksum as the first value, followed by the
.\"                        equivalent of the standard UNIX wc (word
.\"                        count) utility output of lines, words, and
.\"                        characters.  This is produced by Robert
.\"                        Solovay's checksum utility.",
.\"  }
.\" ====================================================================
.TH WWWSEEK 1 "02 December 1998" "Version 1.00"
.\"======================================================================
.SH NAME
wwwseek \- search multiple World-Wide Web sites in parallel
.\"=====================================================================
.SH SYNOPSIS
.B wwwseek
[
.BI "\-v JOBS=" nn
]
[
.BI "\-v TIMEOUT=" nn
]
.if n .ti +9n
[
.BI "\-v TMPDIR=" dirname
]
[
.BI "\-v TRIES=" nn
]
.if t .ti +.5i
.if n .ti +9n
.I pattern(s)
.RI > outfile
.\"=====================================================================
.SH DESCRIPTION
Interactive Web searching in a browser client can be extremely
tedious, since each search engine has a different user interface, and
each displays a list, possibly spanning multiple screens, of hypertext
links to Web documents that match the specified patterns.  The user must
then follow each link in turn, wait for the document text, and usually,
associated images, to be downloaded, then invoke the primitive search
facility provided by the Web browser to find the patterns sought.
.PP
.B wwwseek
removes most of this tedium, produces results very much faster, and
permits more powerful search mechanisms.
.PP
.B wwwseek
queries several major Internet search engines for lists of Web
documents containing user-specified patterns, then creates a temporary
shell script that retrieves those Web documents
.IR "in parallel" ,
ignoring duplicates, and writes them to
.IR stdout .
.PP
The output file can later be searched in a text editor, or with
pattern matching utilities like
.BR agrep (1)
or
.BR egrep (1),
and the searches can be repeated in the local output file, with
variations, as often as needed, without having to retrieve documents from
the Web again.  The surrounding context options,
.BI \-A " nnn,"
.BI \-B " nnn,"
and
.BI \-  nnn,
of the GNU implementation of
.BR egrep (1),
or the
.I occur
command
in GNU
.BR emacs (1),
are particularly useful in reducing the amount of material to be
looked at, and determining whether the match is useful or not.
.PP
If you find that HTML markup clutters your search output, obscuring
the patterns that you are looking for, consider prefiltering it with a
utility like
.BR dehtml (1)
to remove the markup.
.PP
Because Web sites are frequently inaccessible, and potentially
hundreds or thousands may be contacted by this program, the normal 15
min timeout used by
.BR wget (1)
to contact a host to fetch a document is reduced to 15 sec. This can
be changed by a command-line option.
.PP
Because
.B wwwseek
can sometimes take several minutes, or even hours, to run, it produces
a progress report on
.I stderr
showing the current document number and uniform resource locator (URL)
that it is fetching.  Because the searches proceed in parallel at
unpredictable speeds, the document numbers will often be somewhat out
of order.
.PP
The output file begins with a three-line HTML comment recording the
.B wwwseek
command line, the current date and time, and the hostname on which
.B wwwseek
was run.
.PP
Each retrieved file is copied to a separate page of the output file,
beginning with an ASCII formfeed (Ctl-L) character, and followed by a
distinctive HTML comment of the form
.nf
        <!-- wwwseek URL="..." -->
.fi
to record the origin of each document.  This is convenient if you
later wish to return to that site, perhaps to find other related
documents.
.PP
HTML comments are preserved by
.BR dehtml (1),
so you can still identify document origins even when
.B dehtml
has been used to remove HTML markup.
.\"=====================================================================
.SH OPTIONS
Command-line options must precede the search patterns,
and option letter case is
.IR significant .
.\"-----------------------------------------------
.TP \w'\-v\&TIMEOUT=nn'u+3n
.BI "\-v JOBS=" nn
Set the number of parallel jobs retrieving Web documents.  The default is
25, and any value outside the range 1 .\|.\|. 25 will be reset to the
default.  Each subprocess requires about 2MB of memory, plus space in
.I /tmp
to hold the retrieved file.  If either of these proves to be a
limiting resource on small systems, then a smaller
.B JOBS
value can be specified on the command line.  However, since the work
is largely network-I/O-bound, the elapsed time for a single search is
expected to be sped up by as much as a factor of
.BR JOBS ,
so large values are desirable.
.\"-----------------------------------------------
.TP
.BI "\-v TIMEOUT=" nn
Specify the maximum number of seconds to wait for a read request: the
default is 15.
.\"-----------------------------------------------
.TP
.BI "\-v TMPDIR=" dirname
Specify an alternate directory for the temporary shell script and
output files from parallel retrievals.  The default is
.IR /tmp .
.PP
This variable may also be specified in the environment, as is
conventional practice in the UNIX world.
.\"-----------------------------------------------
.TP
.B "\-v TRIES=nn"
Specify the maximum number of retries made to contact a remote host;
the default is 4.
.\"=====================================================================
.SH "SEARCH PATTERNS"
The several seach engines invoked by
.B wwwseek
lack a common advanced search string specification, although all treat
a list of one or more words as if the words were interspersed with
Boolean OR operators, so that any Web document whose contents match
one or more of the words will be returned in the results list.
.PP
Alternatively, the words can be prefixed with plus signs to indicate
that they are required to be found; this effectively turns the
implicit OR operators into AND operators.
.PP
Search patterns should usually be entered in lowercase letters, which
all engines interpret to mean matching without regard to lettercase.
Uppercase letters in patterns generally request exact matching.
.PP
Some, but not all, search engines recognize a terminal asterisk in a
pattern to mean zero or more following characters, so the pattern
.I "box*"
would match
.IR box ,
.IR boxcar ,
.IR boxed ,
.IR boxes ,
.IR boxing ,
.IR boxwood ,
.IR boxy ", .\|.\|.
.PP
A few engines recognize
.I altavista
advanced search strings, e.g.,
.nf
        arg1 NEAR arg2
        arg1 '~' arg2
.PP
        arg1 AND arg2
        arg1 '&' arg2
.PP
        arg1 OR arg2
        arg1 '|' arg2
.PP
        arg1 AND NOT arg2
        arg1 '&' '!' arg2
.PP
        arg1 'AND' arg2 'AND' arg3
        arg1 '&' arg2 '&' arg3
.PP
        arg1 OR arg2 OR arg3
        arg1 '|' arg2 '|' arg3
.fi
.PP
Clearly, the named Boolean operators are more convenient than the
single-character ones, which need to be protected by shell quotes.
.PP
The safest common syntax is one or more words or quoted strings, each
prefixed with a plus, meaning all must be found:
.nf
        +arg1 +"arg 2" +arg3 +"arg 4 with more blanks"
.fi
.PP
Parenthesized expressions in search strings are not yet handled by
.BR wwwseek ,
or recognized by more than a few search engines.  They can be passed
through by separating them with plus signs: the
.I altavista
advanced search string
.nf
        arg1 AND NOT ( arg2 OR arg3 )
.fi
can be encoded as
.nf
        arg1 AND NOT '(+arg2+OR+arg3+)'
.fi
.\"=====================================================================
.SH FILES
These temporary files are created in the directory defined by
.BR TMPDIR :
.TP \w'\fIws\fP\fRnnnnnn\fP\fI.tm.\fP\fRkk\fP'u+3n
.IR ws nnnnnn .sh
Temporary shell script;
.I nnnnnn
is a random number intended to make name collisions with other
simultaneous uses of
.B wwwseek
unlikely.
.TP
.IR ws nnnnnn .tm. kk
Temporary output from a parallel document retrieval;
.I kk
is a sequence number from 00 to
.BR JOBS "- 1."
.PP
Unless
.B wwwseek
is unexpectedly terminated, these temporary files are normally
deleted on completion.
.\"=====================================================================
.SH "ENVIRONMENT VARIABLES"
.TP
.B TMPDIR
Directory where temporary files are to be created (default:
.IR /tmp ).
.\"=====================================================================
.SH "SEE ALSO"
.BR agrep (1),
.BR amaya (1),
.BR arena (1),
.BR chimera (1),
.BR dehtml (1),
.BR egrep (1),
.BR emacs (1)
.BR grail (1),
.BR hotjava (1),
.BR ie (1),
.BR lynx (1),
.BR netscape (1),
.BR wget (1),
.BR xmosaic (1).
.\"=====================================================================
.SH AUTHOR
.nf
Nelson H. F. Beebe, Ph.D.
Center for Scientific Computing
University of Utah
Department of Mathematics, 322 INSCC
155 S 1400 E RM 233
Salt Lake City, UT 84112-0090
USA
Tel: +1 801 581 5254
FAX: +1 801 585 1640, +1 801 581 4148
Email: <beebe@math.utah.edu>
WWW URL: http://www.math.utah.edu/~beebe
.fi
.\"==============================[The End]==============================
